# Teramap bundles

These are bundles generated by webpack. Do not edit these files directly, but edit the files outside of this directory and use

```
npm run bundle
```
or
```
npm run watch
```

to update them.
